pub struct BinaryViewType {
pub handle: *mut BNBinaryViewType,
}Expand description
A BinaryViewType acts as a factory for BinaryView objects.
Each file format will have its own type, such as PE, ELF, or Mach-O.
Fields
handle: *mut BNBinaryViewTypeImplementations
Sourceimpl BinaryViewType
impl BinaryViewType
pub fn list_all() -> Array<BinaryViewType>
Sourcepub fn valid_types_for_data(data: &BinaryView) -> Array<BinaryViewType>
pub fn valid_types_for_data(data: &BinaryView) -> Array<BinaryViewType>
Enumerates all view types and checks to see if the given raw BinaryView is valid,
returning only those that are.